-- MySQL Workbench Forward Engineering

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- -----------------------------------------------------
-- Schema formula1
-- -----------------------------------------------------
DROP SCHEMA IF EXISTS `formula1` ;

-- -----------------------------------------------------
-- Schema formula1
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `formula1` DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci ;
USE `formula1` ;

-- -----------------------------------------------------
-- Table `formula1`.`Korisnik`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Korisnik` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Korisnik` (
  `Ime` VARCHAR(45) NOT NULL,
  `Prezime` VARCHAR(45) NOT NULL,
  `Godina_rodjenja` INT NOT NULL,
  PRIMARY KEY (`Ime`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Osoba`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Osoba` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Osoba` (
  `Username` VARCHAR(45) NOT NULL,
  `Password` VARCHAR(45) NULL,
  PRIMARY KEY (`Username`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Drzava`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Drzava` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Drzava` (
  `IdDrz` INT NOT NULL AUTO_INCREMENT,
  `Naziv` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`IdDrz`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Tim`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Tim` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Tim` (
  `IdTim` INT NOT NULL AUTO_INCREMENT,
  `Naziv` VARCHAR(45) NULL,
  PRIMARY KEY (`IdTim`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Vozac`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Vozac` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Vozac` (
  `Broj` INT NOT NULL,
  `Ime` VARCHAR(45) NOT NULL,
  `Prezime` VARCHAR(45) NOT NULL,
  `Godina_rodjenja` INT NOT NULL,
  `IdDrz` INT NOT NULL,
  `IdTim` INT NOT NULL,
  PRIMARY KEY (`Broj`),
  INDEX `fk_Vozac_Drzava_idx` (`IdDrz` ASC),
  INDEX `fk_Vozac_Tim1_idx` (`IdTim` ASC),
  CONSTRAINT `fk_Vozac_Drzava`
    FOREIGN KEY (`IdDrz`)
    REFERENCES `formula1`.`Drzava` (`IdDrz`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Vozac_Tim1`
    FOREIGN KEY (`IdTim`)
    REFERENCES `formula1`.`Tim` (`IdTim`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Trka`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Trka` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Trka` (
  `IdTrk` INT NOT NULL AUTO_INCREMENT,
  `Naziv` VARCHAR(45) NOT NULL,
  `Staza` VARCHAR(45) NOT NULL,
  `Broj_krugova` INT NOT NULL,
  `Datum` DATE NULL,
  PRIMARY KEY (`IdTrk`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Staza`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Staza` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Staza` (
  `Naziv` VARCHAR(45) NOT NULL,
  `Godina_otvaranja` INT NOT NULL,
  `Duzina` INT NOT NULL,
  `Max_broj_posetilaca` INT NULL,
  `Adresa` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`Naziv`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Rezultat`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Rezultat` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Rezultat` (
  `IdRez` INT NOT NULL AUTO_INCREMENT,
  `Ukupno_vreme` TIME(3) NOT NULL,
  `Najbrzi_krug` TIME(3) NOT NULL,
  `Broj_poena` INT NOT NULL,
  `Vozac_Broj` INT NOT NULL,
  `IdTrk` INT NOT NULL,
  PRIMARY KEY (`IdRez`),
  INDEX `fk_Rezultat_Vozac1_idx` (`Vozac_Broj` ASC),
  INDEX `fk_Rezultat_Trka1_idx` (`IdTrk` ASC),
  CONSTRAINT `fk_Rezultat_Vozac1`
    FOREIGN KEY (`Vozac_Broj`)
    REFERENCES `formula1`.`Vozac` (`Broj`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Rezultat_Trka1`
    FOREIGN KEY (`IdTrk`)
    REFERENCES `formula1`.`Trka` (`IdTrk`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Sektor`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Sektor` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Sektor` (
  `IdSek` INT NOT NULL AUTO_INCREMENT,
  `Naziv` VARCHAR(45) NULL,
  `Broj_redova` INT NULL,
  `Broj_sedista` INT NULL,
  `Cena` INT NULL,
  `IdTrk` INT NOT NULL,
  PRIMARY KEY (`IdSek`),
  INDEX `fk_Sektor_Trka1_idx` (`IdTrk` ASC),
  CONSTRAINT `fk_Sektor_Trka1`
    FOREIGN KEY (`IdTrk`)
    REFERENCES `formula1`.`Trka` (`IdTrk`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Tip_karte`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Tip_karte` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Tip_karte` (
  `Kategorija` CHAR NOT NULL,
  `IdSek` INT NOT NULL,
  PRIMARY KEY (`Kategorija`, `IdSek`),
  INDEX `fk_Tip_karte_Sektor1_idx` (`IdSek` ASC),
  CONSTRAINT `fk_Tip_karte_Sektor1`
    FOREIGN KEY (`IdSek`)
    REFERENCES `formula1`.`Sektor` (`IdSek`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `formula1`.`Karta`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `formula1`.`Karta` ;

CREATE TABLE IF NOT EXISTS `formula1`.`Karta` (
  `idKar` INT NOT NULL AUTO_INCREMENT,
  `IdSek` INT NOT NULL,
  `Ime` VARCHAR(45) NOT NULL,
  `Broj_karata` INT NULL,
  PRIMARY KEY (`idKar`),
  INDEX `fk_Karta_Sektor1_idx` (`IdSek` ASC),
  INDEX `fk_Karta_Korisnik1_idx` (`Ime` ASC),
  CONSTRAINT `fk_Karta_Sektor1`
    FOREIGN KEY (`IdSek`)
    REFERENCES `formula1`.`Sektor` (`IdSek`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Karta_Korisnik1`
    FOREIGN KEY (`Ime`)
    REFERENCES `formula1`.`Korisnik` (`Ime`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
